# Release Notes 
## Run Details
- Workflow: Python package CI/CD 
- Head Branch: bugfix/skip-1 
- Head SHA: db6c284b7e99af64a0d31ae71a2fa3d49e8ad522 

## Pull Requests
**38** Update python-package-cicd.yml
### Commits
  - **9e9ae0e7c2034cd6a0594da876688c9b17e52572** Update python-package-cicd.yml
  - **58dd415b52204a02c094571610aee28ff0ada888** build: update docs
 &gt;
 &gt;
 skip-checks: true
  - **0c135c8ab7526bd8e3ebf0c9719b6ee74e36fd54** build: update docs
 &gt;
 &gt;
 skip-checks: true
  - **0575d8940e03ae2a0218055bd5b114e7f6e110d8** Update python-package-cicd.yml
  - **b6377580f1a5eef6e4e31a10c3d91f7fe1fb897c** Update python-package-cicd.yml
  - **ec7a8d7c3c60ab2c71e68372f481c28563b681e0** Update python-package-cicd.yml
  - **4e3c96965ddb32f0c805197531899faee81bb745** Update python-package-cicd.yml
  - **f74ebeb795f1e578c7acb84ffb6719a640f0164c** Update python-package-cicd.yml
  - **3972d902322a18492de9b58090b2c6ed11f74335** Update python-package-cicd.yml
  - **5c6c02fa3a653ad6adb7fe5a85ac5094b4df5873** Update python-package-cicd.yml
  - **6fe41e64a63c0d9163162b1e83c806ce3ea41a30** Update python-package-cicd.yml
  - **4985ffc757633e342a8ace0efac55336ff214556** Update python-package-cicd.yml
  - **01e6f181e3f4445fba3c3d2f11a12a8794d10012** Merge 4985ffc757633e342a8ace0efac55336ff214556 into fba29d10e0b66981ceea4bc5f1cb6ee39b895582
  - **e648aa72c39c5dc95b901974e4e1b79637fd7d6d** Automated report \n
&gt; \n
&gt; \n
skip-checks: true
  - **6c87776c6fe3b7db68e3362dc04e8fd973b66b86** Update python-package-cicd.yml
  - **b9775753fdb4f1d17b1b62a133c9f7d6d76dae21** Update python-package-cicd.yml
  - **83d84990b7c192199f3de726620c40b3270ea803** Merge b9775753fdb4f1d17b1b62a133c9f7d6d76dae21 into fba29d10e0b66981ceea4bc5f1cb6ee39b895582
  - **d43c976718aef083a19e933571382cb9c73cf563** Automated report
&gt;
&gt;
skip-checks: true
  - **c04c6839e841bd4ea2286b9f6385e66a815e62b6** Update python-package-cicd.yml
  - **e3c9ca9343c23b3eea140ca75c9eb294e5ce1245** Merge c04c6839e841bd4ea2286b9f6385e66a815e62b6 into fba29d10e0b66981ceea4bc5f1cb6ee39b895582
  - **0b1a506d9d364817afd2eccb62f739ce4bf3bec2** Automated report

skip-checks: true
  - **a2e78293d40b086116ecb960941c6220f33e47df** Update python-package-cicd.yml
  - **4148b18b4b7add75c09e0f7cc959d5b3fdc47ca9** build: update docs skip-checks: true
  - **48ba621b0cdc407592e8ffbf56fa029df9adb927** build: update docs skip-checks: true
  - **9daec40fa08d00964515554fd42b09786e3ba21f** Update python-package-cicd.yml
  - **e2d05c7d5348d0b917a5ac4c797827770b1c6e79** build: update docs

skip-checks: true
  - **6662df791439e71034f881906a9dd7eee343f6af** build: update docs

skip-checks: true
  - **8123457a47e79c37dcd4085774460d50428e559d** Update python-package-cicd.yml
  - **8e228cff0e4e71f2e797672852f2c0439adbc35c** build: update docs

skip-checks:true
  - **b627d2f158018dca20b0c84fa4b2f401e1f134bd** Update python-package-cicd.yml
### Comments
 - ## Unit Test Results
1 files  ±0  1 suites  ±0   0s [:stopwatch:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;duration of all tests&quot;) ±0s
1 tests ±0  1 [:heavy_check_mark:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;passed tests&quot;) ±0  0 [:zzz:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;skipped / disabled tests&quot;) ±0  0 [:x:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;failed tests&quot;) ±0 

Results for commit 9e9ae0e7. ± Comparison against base commit fba29d10.

 - ## Unit Test Results
1 files  ±0  1 suites  ±0   0s [:stopwatch:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;duration of all tests&quot;) ±0s
1 tests ±0  1 [:heavy_check_mark:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;passed tests&quot;) ±0  0 [:zzz:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;skipped / disabled tests&quot;) ±0  0 [:x:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;failed tests&quot;) ±0 

Results for commit db6c284b. ± Comparison against base commit fba29d10.

:recycle: This comment has been updated with latest results.

### linkedIssues
    
